==> strela-java-sdk-0.0.1-sources.jar: MinecraftDeploymentSpec.java <==
package dev.strela.v1;

@com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
@com.fasterxml.jackson.annotation.JsonPropertyOrder({"replicas","template","type"})
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@javax.annotation.processing.Generated("io.fabric8.java.generator.CRGeneratorRunner")
public class MinecraftDeploymentSpec implements io.fabric8.kubernetes.api.model.KubernetesResource {

    /**
     * Foo is an example field of MinecraftDeployment. Edit minecraftdeployment_types.go to remove/update
     */
    @com.fasterxml.jackson.annotation.JsonProperty("replicas")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("Foo is an example field of MinecraftDeployment. Edit minecraftdeployment_types.go to remove/update")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private Long replicas;

    public Long getReplicas() {
        return replicas;
    }

    public void setReplicas(Long replicas) {
        this.replicas = replicas;
    }

    @com.fasterxml.jackson.annotation.JsonProperty("template")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private dev.strela.v1.minecraftdeploymentspec.Template template;

    public dev.strela.v1.minecraftdeploymentspec.Template getTemplate() {
        return template;
    }

    public void setTemplate(dev.strela.v1.minecraftdeploymentspec.Template template) {
        this.template = template;
    }

    @com.fasterxml.jackson.annotation.JsonProperty("type")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private String type;

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }
}

==> strela-java-sdk-0.0.4-sources.jar: MinecraftDeploymentSpec.java <==
package dev.strela.v1;

@com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
@com.fasterxml.jackson.annotation.JsonPropertyOrder({"replicas","template"})
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@javax.annotation.processing.Generated("io.fabric8.java.generator.CRGeneratorRunner")
public class MinecraftDeploymentSpec implements io.fabric8.kubernetes.api.model.KubernetesResource {

    /**
     * Foo is an example field of MinecraftDeployment. Edit minecraftdeployment_types.go to remove/update
     */
    @com.fasterxml.jackson.annotation.JsonProperty("replicas")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("Foo is an example field of MinecraftDeployment. Edit minecraftdeployment_types.go to remove/update")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private Long replicas;

    public Long getReplicas() {
        return replicas;
    }

    public void setReplicas(Long replicas) {
        this.replicas = replicas;
    }

    @com.fasterxml.jackson.annotation.JsonProperty("template")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private dev.strela.v1.minecraftdeploymentspec.Template template;

    public dev.strela.v1.minecraftdeploymentspec.Template getTemplate() {
        return template;
    }

    public void setTemplate(dev.strela.v1.minecraftdeploymentspec.Template template) {
        this.template = template;
    }
}
